Skip to contents

This data package contains anonymized student-level records for 98,000 undergraduates from three US institutions from 1988 through 2018 organized in four data tables keyed by student ID. Student-level data refers to information collected by undergraduate institutions on individual students including demographics, programs and academic standing by term, individual courses, grades, and degrees. These data are a proportionate stratified sample of the MIDFIELD database, but are not suitable for drawing inferences about program attributes or student experiences—'midfielddata' provides practice data, not research data. The 'midfieldr' package, available at < https://CRAN.R-project.org/package=midfieldr>, is designed to interact with 'midfielddata' as well as with the full MIDFIELD database, the management of which was transferred to the American Society for Engineering Education in 2023. The development of 'midfieldr' and 'midfielddata' was supported by the US National Science Foundation through grant numbers 1545667 and 2142087.

Author

Maintainer: Richard Layton graphdoctor@gmail.com [copyright holder]

Authors:

  • Richard Layton graphdoctor@gmail.com [copyright holder]

  • Russell Long [copyright holder]

  • Matthew Ohland ohland@purdue.edu [copyright holder]

  • Marisa Orr [copyright holder]

  • Susan Lord [copyright holder]

Other contributors:

  • US National Science Foundation [funder]